@@ -98,6 +98,8 @@ class NetConfig(object):
             self.add_ovs_patch_port(obj)
         elif isinstance(obj, objects.IbInterface):
             self.add_ib_interface(obj)
+        elif isinstance(obj, objects.IbChildInterface):
+            self.add_ib_child_interface(obj)
         elif isinstance(obj, objects.OvsDpdkPort):
             self.add_ovs_dpdk_port(obj)
         elif isinstance(obj, objects.OvsDpdkBond):
@@ -215,6 +217,14 @@ class NetConfig(object):
         """
         raise NotImplementedError("add_ib_interface is not implemented.")
 
+    def add_ib_child_interface(self, ib_child_interface):
+        """Add an InfiniBand child interface object to the net config object.
+
+        :param ib_child_interface: The InfiniBand child
+        interface object to add.
+        """
+        raise NotImplementedError("add_ib_child_interface is not implemented.")
+
     def add_ovs_dpdk_port(self, ovs_dpdk_port):
         """Add a OvsDpdkPort object to the net config object.
 
@@ -311,6 +321,10 @@ class NetConfig(object):
     def ifdown(self, interface, iftype='interface'):
         msg = 'running ifdown on %s: %s' % (iftype, interface)
         self.execute(msg, '/sbin/ifdown', interface, check_exit_code=False)
+        if utils.is_active_nic(interface):
+            msg = '%s %s is up, trying with ip command' % (iftype, interface)
+            self.execute(msg, '/sbin/ip',
+                         'link', 'set', 'dev', interface, 'down')
 
     def ifup(self, interface, iftype='interface'):
         """Run 'ifup' on the specified interface
