@@ -835,7 +835,7 @@ class TestBridge(base.TestCase):
 """
         bridge = objects.object_from_json(json.loads(data))
         self.assertTrue(3 == len(bridge.ovs_extra))
-        self.assertItemsEqual(["bar",
+        self.assertCountEqual(["bar",
                                "set bridge br-foo fail_mode=standalone",
                                "del-controller br-foo"],
                               bridge.ovs_extra)
@@ -849,7 +849,7 @@ class TestBridge(base.TestCase):
 }
 """
         bridge = objects.object_from_json(json.loads(data))
-        self.assertItemsEqual(["bar",
+        self.assertCountEqual(["bar",
                                "set bridge br-foo fail_mode=standalone",
                                "del-controller br-foo"],
                               bridge.ovs_extra)
@@ -2443,18 +2443,3 @@ class TestOvsRequiredObjects(base.TestCase):
         expected = 'OvsDpdkPort cannot be created as OpenvSwitch is not ' \
                    'installed.'
         self.assertIn(expected, six.text_type(err))
-
-
-class TestLinuxTap(base.TestCase):
-
-    def test_linux_tap_from_json(self):
-        data = """{
-"type": "linux_tap",
-"name": "tap0",
-"nm_controlled": false
-}
-"""
-
-        linux_tap = objects.object_from_json(json.loads(data))
-        self.assertEqual("tap0", linux_tap.name)
-        self.assertEqual(False, linux_tap.nm_controlled)
